<template>
  <div class="policy-page">
    <!-- Header -->
    <header class="policy-header bg-white shadow-sm py-3 sticky-top">
      <div class="container-fluid">
        <div class="d-flex align-items-center justify-content-between">
          <nuxt-link to="/" class="text-default fs-4">
            <i class="icon icon-regular-angle-right"></i>
          </nuxt-link>
          <h4 class="m-0 fw-bold">
            <i class="icon icon-regular-wallet ms-2"></i>
            {{ t('wallet_policy.title') }}
          </h4>
          <div style="width: 24px"></div>
        </div>
      </div>
    </header>

    <!-- Main Content -->
    <main class="container-fluid pt-4 pb-5 mb-5">
      <!-- Hero Section -->
      <section class="policy-hero rounded-4 p-4 mb-5">
        <h5 class="fw-bold text-default mb-3">{{ t('wallet_policy.hero_title') }}</h5>
        <p class="mb-0">{{ t('wallet_policy.hero_text') }}</p>
      </section>

      <!-- Rules List -->
      <div class="rules-list">
        <div
            class="rule-item bg-white p-4 mb-3 rounded-3 shadow-sm"
            v-for="(rule, index) in rules"
            :key="index"
        >
          <div class="d-flex align-items-start">
            <span class="badge bg-default text-dark ms-3 mt-1">{{ index + 1 }}</span>
            <p class="mb-0">{{ rule }}</p>
          </div>
        </div>
      </div>

      <!-- Important Card -->
      <div class="policy-card default mt-4">
        <i class="fas fa-exclamation-triangle text-default"></i>
        <div>
          <h5 class="text-default">{{ t('wallet_policy.important_title') }}</h5>
          <p class="mb-0">{{ t('wallet_policy.important_text') }}</p>
        </div>
      </div>
    </main>
  </div>
</template>

<script setup>
import { useI18n } from 'vue-i18n';
const { t, locale } = useI18n();

definePageMeta({
  layout: "web"
});

const rules = ref([
  t('wallet_policy.rules.1'),
  t('wallet_policy.rules.2'),
  t('wallet_policy.rules.3'),
  t('wallet_policy.rules.4'),
  t('wallet_policy.rules.5')
]);
</script>

<style scoped>
/* استفاده از استایل‌های یکپارچه با صفحه قبلی */
.policy-hero {
  background: rgba(255, 152, 0, 0.1);
  border: 1px solid rgba(255, 152, 0, 0.2);
}

.policy-card {
  background: white;
  border-radius: 12px;
  padding: 20px;
  box-shadow: 0 5px 15px rgba(0, 0, 0, 0.05);
  display: flex;
  gap: 15px;
  border-left: 4px solid #ff9800;
}

.rule-item {
  transition: all 0.3s ease;
  border-left: 3px solid #ff9800;
}

.rule-item:hover {
  transform: translateX(5px);
  box-shadow: 0 5px 15px rgba(255, 152, 0, 0.1);
}

/* استفاده از کلاس‌های Bootstrap برای کاهش CSS اختصاصی */
</style>